@@ -78,6 +78,35 @@ class Client:
     def set_data(self, id, data: bytes):
         self.__post(f'{self.__system_url}/objects/{id}/data', data, is_json=False)
 
+    def get_abstracts(self, id, include_self=False, include_direct=True, include_transitive=False):
+        return self.__get(
+            f'{self.__system_url}/objects/{id}/abstracts'
+            f'?self={"1" if include_self else "0"}'
+            f'&direct={"1" if include_direct else "0"}'
+            f'&transitive={"1" if include_transitive else "0"}')['ids']
+
+    def get_specials(self, id, include_self=False, include_direct=True, include_transitive=False):
+        return self.__get(
+            f'{self.__system_url}/objects/{id}/specials'
+            f'?self={"1" if include_self else "0"}'
+            f'&direct={"1" if include_direct else "0"}'
+            f'&transitive={"1" if include_transitive else "0"}')['ids']
+
+    def set_value(self, id, field, value):
+        pass
+
+    def add_value(self, id, field, value):
+        pass
+
+    def get_value(self, id, field):
+        pass
+
+    def get_values(self, id):
+        pass
+
+    def set_values(self, id):
+        pass
+
     def stream(self) -> Stream:
         return Stream(self, self.__stream_url)
 
